/*
 * Copyright (c) 2014 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global define*/

/**
 * Page helper module.
 * @requires {@link core/window}
 * @namespace ArchiveManager/helpers/page
 * @memberof  ArchiveManager/helpers
 */
define({
    name: 'helpers/page',
    requires: [
        'core/window'
    ],
    def: function helpersPage(window) {
        'use strict';

        /**
         * Document width.
         * @type {number}
         */
        var width = window.document.width,

            /**
             * Document height.
             * @type {number}
             */
            height = window.document.height;

        /**
         * Returns document width.
         * @return {number}
         * @memberof ArchiveManager/helpers/page
         */
        function getWidth() {
            return width;
        }

        /**
         * Returns document height.
         * @return {number}
         * @memberof ArchiveManager/helpers/page
         */
        function getHeight() {
            return height;
        }

        return {
            getWidth: getWidth,
            getHeight: getHeight
        };
    }
});
